@@ -18,6 +18,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
+
+/* ***** Mikeb 4.5.1 Changes *****
+ * Most changes have been made here otherwise its just the removal of connected functions.
+ * Gui tidied up and enlarged.
+ * Removed broken and redundant patch making code as it seems like it is eternally broken so its just a simple file difference viewer.
+ * TODO fix population of combo boxes when a folder is selected...IF thats actually a useful function..otherwise lob that code too and just have 2 entry boxes instead.
+ * */
+
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -62,46 +71,7 @@ static void cb_do_patch (GtkWidget * widget, gpointer data);
 static void cb_do_diff (GtkWidget * widget, gpointer data);
 
 /******************** CB section ************************/
-#if 0
-static gint
-tag_event_handler (GtkTextTag *tag, GtkWidget *widget, GdkEvent *event,
-                  const GtkTextIter *iter, gpointer user_data)
-{
-  return FALSE;	
-}
-static void
-setup_tags (void)
-{
-  GdkColor color;
-  tagRed = gtk_text_tag_new ("bg_red");
-//  tag = gtk_text_buffer_create_tag ((GtkTextBuffer *)text_buffer[1], "bg_red", NULL);
 
-  color.blue = color.green = 0;
-  color.red = 0xffff;
-  g_object_set (G_OBJECT (tagRed),
-                "background_gdk", &color,
-                NULL);
-  g_signal_connect (G_OBJECT (tagRed),
-		    "event",
-		    G_CALLBACK (tag_event_handler),
-		    NULL);
-  
-  tagYellow = gtk_text_tag_new ("fg_yellow");
-  //tag = gtk_text_buffer_create_tag (buffer, "fg_yellow", NULL);
-
-      
-  color.blue = 0;
-  color.red = color.green = 0xffff;
-  g_object_set (G_OBJECT (tagYellow),
-                "foreground_gdk", &color,
-                NULL);
-  
-  g_signal_connect (G_OBJECT (tagYellow),
-		    "event",
-		    G_CALLBACK (tag_event_handler),
-		    NULL);
-}
-#endif
 gchar *
 get_rcfile(void){
   gchar *xdg_dir=g_build_filename(g_get_home_dir(),".config",NULL);
@@ -142,20 +112,11 @@ GdkPixbuf *xfdiff_icon(void)
 void
 clear_text_buffer (GtkTextBuffer * buffer)
 {
-  /*GtkTextIter *start=NULL,*end=NULL; */
   if (!buffer)
     return;
   gtk_text_buffer_set_text (buffer, "", -1);
-/*	gtk_text_buffer_get_bounds (buffer,start,end);  */
-/*	gtk_text_buffer_delete(buffer,start,end);*/
-}
 
-/*static void  scroll_adjustments(GtkTextView *textview,
-                                            GtkAdjustment *arg1,
-                                            GtkAdjustment *arg2,
-                                            gpointer user_data){
-    ("set-scroll-adjustments");
-}*/
+}
 
 
 static void
@@ -227,15 +188,7 @@ on_drag_data_received (GtkWidget * entry, GdkDragContext * context, gint x, gint
 	if (file[i] == 13)
 	  file[i] = 0;
     }
-    if (patching)
-    {
-      if (checkdir (file))
-	fileD = assign (fileD, file);
-      else
-	fileP = assign (fileP, file);
-    }
-    else
-    {				/* spot 1/3 where filename[1], filename[0] come in */
+
       if (entry == viewR)
       {
 	filename[1] = assign (filename[1], file);
@@ -246,7 +199,7 @@ on_drag_data_received (GtkWidget * entry, GdkDragContext * context, gint x, gint
 	filename[0] = assign (filename[0], file);
 	fileLD = assign (fileLD, checkdir (file) ? file : NULL);
       }
-    }
+
     update_titlesP ();
     cleanF ();
     cleanP ();
@@ -257,239 +210,23 @@ on_drag_data_received (GtkWidget * entry, GdkDragContext * context, gint x, gint
   free (text);
 }
 
-static void
-cb_patchapply (GtkWidget * widget, gpointer data)
-{
-  int undoing;
-  undoing = (int) data;
-  if ((!fileD) || (!fileP))
-  {
-    xf_dlg_warning(diff,("A patch file and directory must be selected first!"));
-    return;
-  }
 
-  if (undoing)
-    reversed = !reversed;
-  applying_patch = 1;
-  do_patch ();
-  applying_patch = 0;
-  if (undoing)
-    reversed = !reversed;
-  if (!check_reject ())
-    xf_dlg_info (diff,(undoing) ? _("Patch has been undone.") : _("Patch has been applied."));
-}
+#define DIFF_MENUS 4
 
 
-/* this function should only be called from diff mode.*/
-static void
-cb_patchmake (GtkWidget * widget, gpointer data)
-{
-  char *patchDL = NULL, *patchDR = NULL;
-  int cancelled = 0;
-  /* select file name for output: */
-
-  patchDR = assign (patchDR, filename[1]);
-  patchDL = assign (patchDL, filename[0]);
-
-  patchO = prompt_outfile (_("Please select a name for the patch file in the next dialog."), patchO);
-  if (!patchO)
-  {
-    cancelled = 1;
-    goto exit_patchmake;
-  }
-
-  if (fileLD)
-    filename[0] = assign (filename[0], fileLD);
-  if (fileRD)
-    filename[1] = assign (filename[1], fileRD);
-
-  if (!filename[0])
-    filename[0] = prompt_path (_(no_left_path), filename[0]);
-  if ((filename[0]) && (!filename[1]))
-    filename[1] = prompt_path (_(no_right_path), filename[1]);
-  if ((!filename[0]) || (!filename[1]))
-    goto exit_patchmake;
-
-  if (!xf_dlg_ask(diff,_("Xfdiff will now start diff.\nPlease be patient (xfdiff might seem to hang).\nDiff will be working")))
-  {
-    cancelled = 1;
-    goto exit_patchmake;
-  }
-
-  if (!do_diff ())
-    xf_dlg_warning(diff,("Patch file could not be created"));
-  else
-  {
-    gchar *number=0;
-    int numL, numR;
-    if (!number)
-      xfdiff_abort (E_MALLOC);
-    numL = max_strip (filename[0]);
-    numR = max_strip (filename[1]);
-    number=g_strdup_printf(_("Strip level for created patch file=%d"),
-	    ((numL < numR) ? numL : numR));
-    show_diag (number);
-    show_diag ("\n");
-    g_free(number);
-    number=g_strdup_printf(_("%s has been created"),patchO);
-    show_diag (number);
-    show_diag ("\n");
-    g_free (number);
-    xf_dlg_info (diff,number);
-
-    show_diag ("(");
-    show_diag (filename[0]);
-    show_diag ("-->");
-    show_diag (filename[1]);
-    show_diag (")\n");
-  }
-
-exit_patchmake:
-  if (cancelled)
-    xf_dlg_warning(diff,("Patch file creation cancelled"));
-  filename[1] = assign (filename[1], patchDR);
-  filename[0] = assign (filename[0], patchDL);
-  patchDR = assign (patchDR, NULL);
-  patchDL = assign (patchDL, NULL);
-  patchO = assign (patchO, NULL);
-  return;
-}
-
-static void
-cb_radio_strip (GtkWidget * widget, gpointer data)
-{
-  static int laststrip = 0;	/* default strip level */
-  strip = ((int) ((long) data));
-  if (strip != laststrip)
-  {
-    gchar *g=g_strdup_printf(_("Strip level now set to %d (-p%d)"), strip, strip);
-    show_diag (g);
-    g_free(g);
-    show_diag ("\n");
-    laststrip = strip;
-    /* reparse to check if null patchfile with that strip: */
-    cleanF ();
-    update_titlesP ();
-    cleanT ();
-    cleanP ();
-    cleanA ();
-  }
-}
-
-/*
-static void cb_toggle_diagnostics(GtkWidget *widget,gpointer data){
-	silent=!silent;
-	if (silent) {
-		show_diag (_("Diff diagnostics disabled.\n"));
-		show_diag (_("(Patch diagnostics remain enabled)\n"));
-	} else {
-		show_diag (_("Diff diagnostics enabled.\n"));
-	}
-#ifdef AUTOSAVE
-	cb_save_defaults(NULL,NULL); 
-#endif	
-}*/
-
-/* 1.2.3 uses 8: */
-#define DIFF_MENUS 8
-/* 1.2.3 uses 10: */
-#define PATCH_MENUS 10
-/* 1.2.3 uses 10 */
-#define STRIP_LEVELS 10
-
-
-static GtkWidget *patchM[PATCH_MENUS];
 static GtkWidget *diffM[DIFF_MENUS];
-static GtkWidget *stripM[STRIP_LEVELS];
+
 
 static void
 hideshow_menus (void)
 {
   gint i;
-  if (patching)
-  {
-    for (i = 0; i < STRIP_LEVELS; i++)
-    {
-      if (i == strip)
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (stripM[i]), TRUE);
-      if (!autostrip)
-      {
-	if (!GTK_WIDGET_VISIBLE (stripM[i]))
-	  gtk_widget_show (stripM[i]);
-      }
-      else
-      {
-	if (GTK_WIDGET_VISIBLE (stripM[i]))
-	  gtk_widget_hide (stripM[i]);
-      }
-    }
 
-    for (i = 0; i < PATCH_MENUS; i++)
-      if ((patchM[i]) && (!GTK_WIDGET_VISIBLE (patchM[i])))
-	gtk_widget_show (patchM[i]);
     for (i = 0; i < DIFF_MENUS; i++)
-      if ((diffM[i]) && (GTK_WIDGET_VISIBLE (diffM[i])))
-	gtk_widget_hide (diffM[i]);
-  }
-  else
-  {
-    for (i = 0; i < STRIP_LEVELS; i++)
-      if (GTK_WIDGET_VISIBLE (stripM[i]))
-	gtk_widget_hide (stripM[i]);
-    for (i = 0; i < PATCH_MENUS; i++)
-      if ((patchM[i]) && (GTK_WIDGET_VISIBLE (patchM[i])))
-	gtk_widget_hide (patchM[i]);
-    for (i = 0; i < DIFF_MENUS; i++)
-      if ((diffM[i]) && (!GTK_WIDGET_VISIBLE (diffM[i])))
 	gtk_widget_show (diffM[i]);
-  }
+
 }
 
-static void
-cb_toggle_mode (GtkWidget * widget, gpointer data)
-{
-  static char *LfileR = NULL, *LfileL = NULL;
-  if ((int) ((long) data))
-  {
-    patching = !patching;
-    cleanA ();
-    cleanP ();
-    cleanT ();
-    cleanF ();
-    if (patching)
-    {
-      LfileR = assign (LfileR, filename[1]);
-      LfileL = assign (LfileL, filename[0]);
-    }
-    else
-    {
-      if (fileRR)
-	remove (fileRR);
-      fileRR = assign (fileRR, NULL);
-      if (fileO)
-	remove (fileO);
-      fileO = assign (fileO, NULL);
-      if (fileI)
-	remove (fileI);
-      fileI = assign (fileI, NULL);
-      filename[1] = assign (filename[1], LfileR);
-      filename[0] = assign (filename[0], LfileL);
-    }
-
-    if (patching)
-    {
-      if (!GTK_WIDGET_VISIBLE (patch_label_box))
-	gtk_widget_show (patch_label_box);
-    }
-    else
-    {
-      if (GTK_WIDGET_VISIBLE (patch_label_box))
-	gtk_widget_hide (patch_label_box);
-    }
-    update_titlesP ();
-  }
-  hideshow_menus ();
-}
 
 static void
 cb_toggle_synchronize (GtkWidget * widget, gpointer data)
@@ -509,9 +246,7 @@ cb_toggle_synchronize (GtkWidget * widget, gpointer data)
     {
       old_adj = current->topLR;
     }
-    if (patching)
-      cb_do_patch (NULL, (gpointer) ((int) 0));
-    else
+
       cb_do_diff (NULL, (gpointer) ((int) 0));
     thisP = head;
     while (thisP)
@@ -529,27 +264,6 @@ cb_toggle_synchronize (GtkWidget * widget, gpointer data)
 
 }
 
-#ifdef GNU_PATCH
-static void
-cb_toggle_verbose (GtkWidget * widget, gpointer data)
-{
-  verbose = !verbose;
-  if (verbose)
-    show_diag (_("Patch verbose diagnostics enabled.\n"));
-  else
-    show_diag (_("Patch verbose diagnostics disabled.\n"));
-#ifdef AUTOSAVE
-  cb_save_defaults (NULL, NULL);
-#endif
-}
-#endif
-
-static void
-cb_toggle_autostrip (GtkWidget * widget, gpointer data)
-{
-  autostrip = !autostrip;
-  hideshow_menus ();
-}
 
 static void
 cb_toggle_show_lineN (GtkWidget * widget, gpointer data)
@@ -579,70 +293,6 @@ cb_toggle_filledP (GtkWidget * widget, gpointer data)
   configure_event (drawA, NULL);
 }
 
-void
-cb_toggle_reversed (GtkWidget * widget, gpointer data)
-{
-  reversed = !reversed;
-
-  GTK_CHECK_MENU_ITEM (REVERSE_TOGGLE)->active = reversed;
-  if (reversed)
-    show_diag (_("Patch will now be assumed reversed.\n"));
-  else
-    show_diag (_("Patch will now be assumed *not* reversed.\n"));
-  if (headF)
-  {
-    /* cleanF(); no need to parse patch file again */
-    cleanP ();
-    cleanA ();
-    cleanT ();
-  }
-}
-
-#if 0
-static void
-cb_select_font (GtkWidget * widget, gpointer data)
-{
-  static char *fnt;
-  int old_lineH;
-
-  GdkFont* ff;
-  ff=gtk_style_get_font(viewR->style);
-
-  /*printf("font=%s\n",fuente); */
-  /*  */
-  /*  */
-  old_lineH = ff->ascent + ff->descent;
-  fnt = xf_fontselect (_("Font selection"), fuente);
-  if (fnt)
-  {
-    the_font = gdk_font_load (fnt);
-    if (the_font == NULL)
-    {
-      xf_dlg_warning(diff,("Could not load specified font\n"));
-      return;
-    }
-    else
-    {
-      int old_silent, old_adj;
-      gtk_style_set_font(style,the_font);
-      fuente = fnt;
-#ifdef AUTOSAVE
-      cb_save_defaults (NULL, NULL);
-#endif
-      old_silent = silent;
-      silent = 1;
-      old_adj = (GTK_ADJUSTMENT (adj)->value) / old_lineH;
-      cb_do_diff (widget, (gpointer) ((int) 0));
-      silent = old_silent;
-      old_adj *= (ff->ascent + ff->descent);
-
-      configure_event (drawA, NULL);
-      gtk_adjustment_set_value (GTK_ADJUSTMENT (adj), old_adj);
-    }
-  }
-
-}
-#endif
 
 static void
 cb_select_colors (GtkWidget * widget, gpointer data)
@@ -655,7 +305,7 @@ cb_select_colors (GtkWidget * widget, gpointer data)
 
   style = gtk_widget_get_style (viewR);
   /* initial colors defined in getdefaults() */
-  /*  */
+
   switch (caso)
   {
   case 1:
@@ -668,14 +318,13 @@ cb_select_colors (GtkWidget * widget, gpointer data)
   if (newcolor)
   {
     int old_silent, old_adj;
-    /* printf("color=0x%x\n",caso);
-       printf("r=0x%x, g=0x%x b=0x%x\n",colorfg.red,colorfg.green ,colorbg.blue); */
+
     set_highlight ();
 
     old_silent = silent;
     silent = 1;
     old_adj = (GTK_ADJUSTMENT (adj)->value);
-/*    if ((filename[1] && filename[0]) || (fileP && fileD)) cb_do_diff (widget, (gpointer) ((int) 0));*/
+
     silent = old_silent;
     gtk_adjustment_set_value (GTK_ADJUSTMENT (adj), old_adj);
 #ifdef AUTOSAVE
@@ -711,13 +360,9 @@ cb_do_patch (GtkWidget * widget, gpointer data)
 
   if (!headF)
   {
-    if (!patching)
+
       cb_do_diff (widget, data);
-    else
-    {
-      do_patch ();
-      check_reject ();
-    }
+
     return;
   }
 
@@ -735,31 +380,23 @@ cb_do_patch (GtkWidget * widget, gpointer data)
   else
   {
     gchar *texto=NULL;
-    if (!patching)
-    {
+
       texto = g_strdup_printf(_("Warning: cannot read from %s"),s);
-    }
-    else
-    {
-      texto = g_strdup_printf(_("%s is not in patch file."),s);
-    }
+
     xf_dlg_info (diff,texto);
     g_free (texto);
-    /*  */
+    
     g_free (s);s=NULL;
     return;
   }
-  if (patching)
-    process_patch (currentF);
-  else
-  {
+
     filename[0] = assign (filename[0], currentF->file);
     filename[1] = assign (filename[1], currentF->newfile);
     do_diff ();
-  }
+ 
   first_diff ();
   update_titlesP ();
-  /*  */
+
   g_free (s);s=NULL;
   return;
 }
@@ -774,25 +411,15 @@ cb_do_diff_new (GtkWidget * widget, gpointer data)
   int argc = 0;
 
 
-  arguments[argc++] = "xfdiff";
-  if (patching)
-    arguments[argc++] = "-p";
+  arguments[argc++] = "xfdiff4";
+
   strcpy (Pstrip, "-P");
   Pstrip[2] = strip + '0';
   Pstrip[3] = 0;
   arguments[argc++] = Pstrip;
-  if (reversed)
-    arguments[argc++] = "-R";
-  else
+
     arguments[argc++] = "-N";
-  if (patching)
-  {
-    arguments[argc++] = "-p";
-    Pleft = fileD;
-    Pright = fileP;
-  }
-  else
-  {
+
     if (fileRD)
       Pright = fileRD;
     else
@@ -801,7 +428,7 @@ cb_do_diff_new (GtkWidget * widget, gpointer data)
       Pleft = fileLD;
     else
       Pleft = filename[0];
-  }
+
   if (Pleft)
     arguments[argc++] = Pleft;
   if ((Pright) && (Pleft))
@@ -810,20 +437,13 @@ cb_do_diff_new (GtkWidget * widget, gpointer data)
 
   if (fork ())
   {				/*  parent will fork to new  */
-    execvp ("xfdiff", arguments);
+    execvp ("xfdiff4", arguments);
     perror ("exec");
     _exit (127);		/* parent never gets here (hopefully) */
   }
   return;
 }
 
-static void
-cb_do_patch_new (GtkWidget * widget, gpointer data)
-{
-  cb_do_diff_new (NULL, NULL);
-  return;
-}
-
 
 void
 cb_save_defaults (GtkWidget * widget, gpointer data)
@@ -850,8 +470,7 @@ cb_save_defaults (GtkWidget * widget, gpointer data)
   fprintf (defaults, "colorbg.red : %d\n", colorbg.red);
   fprintf (defaults, "colorbg.green : %d\n", colorbg.green);
   fprintf (defaults, "colorbg.blue : %d\n", colorbg.blue);
-/*	fprintf(defaults,"silent : %d\n",silent);*/
- /* fprintf (defaults, "font : %s\n", fuente);*/
+
   fprintf (defaults, "filledP : %d\n", filledP);
   fprintf (defaults, "show_lineN : %d\n", show_lineN);
   fprintf (defaults, "synchronize : %d\n", synchronize);
@@ -872,7 +491,7 @@ cb_save_defaults (GtkWidget * widget, gpointer data)
 static void
 cb_about (GtkWidget * widget, gpointer data)
 {
-    gchar *message=g_strdup_printf(_("%s: Graphical differences viewer and patch manager\n%s\nhttp://xffm.sf.net/xfdiff.html\n"),PACKAGE_STRING,PACKAGE_COPYRIGHT);
+    gchar *message=g_strdup_printf(_("%s: Graphical differences viewer\n%s\nhttp://xffm.sf.net/xfdiff.html\nTidied by mikeb\n"),PACKAGE_STRING,PACKAGE_COPYRIGHT);
     show_diag(message);
     g_free(message);
 }
@@ -961,16 +580,11 @@ cb_next_file (GtkWidget * widget, gpointer data)
 
   cleanT ();
   cleanP ();
-  if (patching)
-  {
-    process_patch (currentF);
-  }
-  else
-  {
+
     filename[0] = assign (filename[0], currentF->file);
     filename[1] = assign (filename[1], currentF->newfile);
     do_diff ();
-  }
+
   update_titlesP ();
   first_diff ();
 }
@@ -1010,29 +624,6 @@ cb_get_fileL (GtkWidget * widget, gpointer data)
   cleanP ();
   cleanA ();
 }
-static void
-cb_get_fileD (GtkWidget * widget, gpointer data)
-{
-  fileD = get_the_file (fileD);
-  if (checknotdir (fileD))
-    fileD = assign (fileD, NULL);
-  update_titlesP ();
-
-}
-
-static void
-cb_get_fileP (GtkWidget * widget, gpointer data)
-{
-  fileP = get_the_file (fileP);
-  if (checkdir (fileP))
-  {
-    /* only spot where directories for input is not OK: */
-    xf_dlg_warning(diff,("That is a directory (or symlink)"));
-    fileP = assign (fileP, NULL);
-  }
-  update_titlesP ();
-}
-
 
 
 /********************  GUI section **********************/
@@ -1212,107 +803,39 @@ create_menu (GtkWidget * top)
 
   menubar = gtk_menu_bar_new ();
   gtk_widget_show (menubar);
-  for (i = 0; i < PATCH_MENUS; i++)
-    patchM[i] = NULL;
+
   for (i = 0; i < DIFF_MENUS; i++)
     diffM[i] = NULL;
   /* Create "File" menu */
   menu = shortcut_menu (MENUBAR, menubar, _("File"), NULL, NULL);
   diffM[0] = shortcut_menu (SUBMENU, menu, _("Select left file"), (gpointer) cb_get_fileL, NULL);
   diffM[1] = shortcut_menu (SUBMENU, menu, _("Select right file"), (gpointer) cb_get_fileR, NULL);
-  patchM[0] = shortcut_menu (SUBMENU, menu, _("Select patch file"), (gpointer) cb_get_fileP, NULL);
-  patchM[1] = shortcut_menu (SUBMENU, menu, _("Select directory where to apply patch"), (gpointer) cb_get_fileD, NULL);
-
-  shortcut_menu (EMPTY_SUBMENU, menu, NULL, NULL, NULL);
-  diffM[2] = shortcut_menu (SUBMENU, menu, _("Switch to patch mode"),
-			    /* new text 1.2.3 */
-			    (gpointer) cb_toggle_mode, (gpointer) ((long) 1));
-  patchM[2] = shortcut_menu (SUBMENU, menu, _("Switch to diff mode"),
-			     /* new text 1.2.3 */
-			     (gpointer) cb_toggle_mode, (gpointer) ((long) 1));
 
   shortcut_menu (EMPTY_SUBMENU, menu, NULL, NULL, NULL);
   shortcut_menu (SUBMENU, menu, _("Exit"), (gpointer) delete_event, NULL);
 
   /* Create "Settings" menu */
   menu = shortcut_menu (MENUBAR, menubar, _("Diff Settings"), NULL, NULL);
-/*  shortcut_menu(TOGGLENOT,menu,_("Show diagnostics"),
-		  (gpointer)cb_toggle_diagnostics, (gpointer) silent);*/
-  /*shortcut_menu (SUBMENU, menu, _("Font"), (gpointer) cb_select_font, NULL);*/
+
   shortcut_menu (SUBMENU, menu, _("Highlight text color"), (gpointer) cb_select_colors, (gpointer) ((long) 0));
   shortcut_menu (SUBMENU, menu, _("Highlight background color"), (gpointer) cb_select_colors, (gpointer) ((long) 1));
   shortcut_menu (TOGGLE, menu, _("Fill polygons"), (gpointer) cb_toggle_filledP, (gpointer) filledP);
   shortcut_menu (TOGGLE, menu, _("Show line numbers"), (gpointer) cb_toggle_show_lineN, (gpointer) show_lineN);
 
   shortcut_menu (TOGGLE, menu, _("Use line synchronization voids"),
-		 /* new text 1.2.3 */
+
 		 (gpointer) cb_toggle_synchronize, (gpointer) synchronize);
 
 #ifndef AUTOSAVE
   shortcut_menu (EMPTY_SUBMENU, menu, NULL, NULL, NULL);
   shortcut_menu (SUBMENU, menu, _("Save settings as default"), (gpointer) cb_save_defaults, NULL);
 #endif
-  menu = shortcut_menu (MENUBAR, menubar, _("Patch Settings"), NULL, NULL);
-#ifdef GNU_PATCH
-  shortcut_menu (TOGGLE, menu, _("Verbose patch diagnostics"), (gpointer) cb_toggle_verbose, (gpointer) verbose);
-#endif
-  diffM[3] = shortcut_menu (SUBMENU, menu, _("Patch options only active in patch-mode"),
-			    /* new text 1.2.3 */
-			    NULL, NULL);
 
-  /* watchout, REVERSE_TOGGLE is #define patchM[whatever] at xfdiff.h */
-  patchM[3] = shortcut_menu (TOGGLE, menu, _("Assume patch is reversed"), (gpointer) cb_toggle_reversed, (gpointer) reversed);
-
-  patchM[4] = shortcut_menu (TOGGLE, menu, _("Auto strip level"),
-			     /* new text 1.2.3 */
-			     (gpointer) cb_toggle_autostrip, (gpointer) autostrip);
-
-  {
-    GSList *group = NULL;
-    gint i;
-    for (i = 0; i < 10; i++)
-    {
-      char s[48];
-      sprintf (s, "Strip level %d (-p%d)", i, i);
-      stripM[i] = gtk_radio_menu_item_new_with_label (group, s);
-      group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (stripM[i]));
-      if (i == strip)
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (stripM[i]), TRUE);
-      /*  */
-      gtk_menu_shell_append (GTK_MENU_SHELL (menu), stripM[i]);
-      if (!autostrip)
-	gtk_widget_show (stripM[i]);
-      g_signal_connect (G_OBJECT (stripM[i]), "activate", G_CALLBACK (cb_radio_strip), (gpointer) ((long) i));
-
-    }
-  }
 
   /* Create "Actions" menu */
   menu = shortcut_menu (MENUBAR, menubar, _("Actions"), NULL, NULL);
-  diffM[4] = shortcut_menu (SUBMENU, menu, _("View differences"), (gpointer) cb_do_diff, (gpointer) ((int) 1));
-  diffM[5] = shortcut_menu (SUBMENU, menu, _("View differences in new"), (gpointer) cb_do_diff_new, (gpointer) ((int) 1));
-
-  patchM[5] = shortcut_menu (SUBMENU, menu, _("View patch created differences"),
-			     /* 1.2.3 correction, was: "Do patch" */
-			     (gpointer) cb_do_patch, (gpointer) ((int) 1));
-  patchM[6] = shortcut_menu (SUBMENU, menu, _("View patch created differences in new"),
-			     /* 1.2.3 correction, was: "Do patch in new" */
-			     (gpointer) cb_do_patch_new, (gpointer) ((int) 1));
-#ifdef __GNUC__
-  diffM[6] = shortcut_menu (EMPTY_SUBMENU, menu, NULL, NULL, NULL);
-  diffM[7] = shortcut_menu (SUBMENU, menu, _("Create patch file"), (gpointer) cb_patchmake, (gpointer) ((int) 0));
-/* obsolete:  
-  patchM[7]=shortcut_menu(SUBMENU,menu,_("Create patch file for full directory"),
-		  (gpointer)cb_patchmake,(gpointer)((int) 1));*/
-#endif
-
-  patchM[7] = shortcut_menu (EMPTY_SUBMENU, menu, NULL, NULL, NULL);
-  patchM[8] = shortcut_menu (SUBMENU, menu, _("Apply patch to Hard Drive"),
-			     /* 1.2.3 correction, was: "Apply patch" */
-			     (gpointer) cb_patchapply, (gpointer) ((int) 0));
-  patchM[9] = shortcut_menu (SUBMENU, menu, _("Undo patch to Hard Drive"),
-			     /* 1.2.3 correction, was: "Undo patch" */
-			     (gpointer) cb_patchapply, (gpointer) ((int) 1));
+  diffM[2] = shortcut_menu (SUBMENU, menu, _("View differences"), (gpointer) cb_do_diff, (gpointer) ((int) 1));
+  diffM[3] = shortcut_menu (SUBMENU, menu, _("View differences in new"), (gpointer) cb_do_diff_new, (gpointer) ((int) 1));
 
   /* Create "Help" menu */
   menu = shortcut_menu (MENUBAR, menubar, _("Help"), NULL, NULL);
@@ -1373,7 +896,7 @@ shortcut_button (GtkWidget * box, char *txt, gpointer func, gpointer data,gboole
 GtkWidget *
 create_diff_window (void)
 {
-  GtkWidget *vbox, *vbox1, *vbox1a, *vbox1b, *vbox2;
+  GtkWidget *vbox, *vbox1, *vbox1a, *vbox1b, *vbox2, *vbox3, *vbox4, *hbox3;
   GtkWidget *hbox, *menutop, *handlebox;
   GtkWidget *bbox, *vscrollbar, *button;
   GtkWidget *view, *viewL, *vpaned, *scrolled_window;
@@ -1449,16 +972,15 @@ create_diff_window (void)
   gtk_widget_show (vscrollbar);
 
   /* invisible box : */
-
+/*seems shared button for both modes...messy*/
   patchbox = gtk_hbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox1a), patchbox, TRUE, TRUE, 0);
   gtk_widget_show (patchbox);
-
+/*beware goes  through patch call even in diff mode*/
   titleD = gtk_combo_new ();
-  OKbutton = button = shortcut_button (NULL, GTK_STOCK_APPLY, 
-		  (gpointer) cb_do_patch, (gpointer) ((int) 0),TRUE);
-  view = gtk_text_view_new ();
-
+  
+  OKbutton = button = shortcut_button (NULL, GTK_STOCK_APPLY,  (gpointer) cb_do_patch, (gpointer) ((int) 0),TRUE);
+  
   /* this is the good place for lineH */
   layout = gtk_widget_create_pango_layout(titleD,"W");
   pango_layout_get_pixel_extents(layout, NULL, &logical_rect);
@@ -1466,20 +988,20 @@ create_diff_window (void)
   lineW = 3*logical_rect.width/4;
   g_object_unref(layout);
   
-  titleP = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
-  gtk_text_view_set_cursor_visible ((GtkTextView *) view, FALSE);
-  gtk_text_view_set_editable ((GtkTextView *) view, FALSE);
-  gtk_text_view_set_wrap_mode ((GtkTextView *) view, GTK_WRAP_NONE);
-  gtk_widget_set_size_request (view, sizeL * lineW, 2*lineH);
-  gtk_widget_set_size_request (titleD, sizeL * lineW, 2*lineH);
-
+  titleP = gtk_combo_new ();
+  
+  gtk_widget_set_size_request (titleP, sizeL * lineW , 2*lineH);
+  gtk_widget_set_size_request (titleD, sizeL * lineW , 2*lineH);
+  
+  button = shortcut_button (patchbox,  GTK_STOCK_OPEN, (gpointer) cb_get_fileL, NULL, TRUE);
   gtk_box_pack_start (GTK_BOX (patchbox), titleD, TRUE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (patchbox), button, FALSE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (patchbox), view, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (patchbox), OKbutton, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (patchbox), titleP, TRUE, TRUE, 0);
+  button = shortcut_button (patchbox,   GTK_STOCK_OPEN, (gpointer) cb_get_fileR, NULL,TRUE);
 
-  gtk_widget_show (view);
+  gtk_widget_show (titleP);
   gtk_widget_show (titleD);
-  gtk_widget_show (button);
+  gtk_widget_show (OKbutton);
 
   /* text boxes : */
 
@@ -1497,7 +1019,8 @@ create_diff_window (void)
   gtk_text_view_set_cursor_visible ((GtkTextView *) viewL, FALSE);
   gtk_text_view_set_editable ((GtkTextView *) viewL, FALSE);
   gtk_text_view_set_wrap_mode ((GtkTextView *) viewL, GTK_WRAP_NONE);
-  gtk_widget_set_size_request (viewL, sizeL * lineW, sizeH * lineH);
+  /* boosted size a bit here and below by 1.5*/
+  gtk_widget_set_size_request (viewL, sizeL * lineW *1.5, sizeH * lineH *1.6);
   gtk_container_add (GTK_CONTAINER (scrolled_windowL), viewL);
 
   scrolled_windowR = gtk_scrolled_window_new (NULL, GTK_ADJUSTMENT (adjR));
@@ -1509,40 +1032,31 @@ create_diff_window (void)
   gtk_text_view_set_cursor_visible ((GtkTextView *) viewR, FALSE);
   gtk_text_view_set_editable ((GtkTextView *) viewR, FALSE);
   gtk_text_view_set_wrap_mode ((GtkTextView *) viewR, GTK_WRAP_NONE);
-  gtk_widget_set_size_request (viewR, sizeL * lineW, sizeH * lineH);
+  gtk_widget_set_size_request (viewR, sizeL * lineW *1.5, sizeH * lineH *1.6);
   gtk_container_add (GTK_CONTAINER (scrolled_windowR), viewR);
-  drawA = gtk_drawing_area_new ();
   
-  /*layout = gtk_widget_create_pango_layout(titleD, drawA_width());
-  pango_layout_get_pixel_extents(layout, NULL, &logical_rect);
-  drawW= logical_rect.width * 2;
-  g_object_unref(layout);*/
-
+  /*drawA shows the linked line numbers between panes..must be left as is to work properly*/
+  drawA = gtk_drawing_area_new ();
 
   gtk_box_pack_start (GTK_BOX (hbox), scrolled_windowL, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), drawA, FALSE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), scrolled_windowR, TRUE, TRUE, 0);
 
- /* {
-      PangoFontDescription *desc;
-      desc = pango_font_description_from_string (font);
-      if (desc) {
-            gtk_widget_modify_font (widget, desc);
-        }
-  }*/
   gtk_widget_show (scrolled_windowL);
   gtk_widget_show (viewL);
   gtk_widget_show (drawA);
   gtk_widget_show (viewR);
   gtk_widget_show (scrolled_windowR);
 
-/* diagnostics */
-  bbox = gtk_vbox_new (TRUE, 0);
-  gtk_paned_pack2 (GTK_PANED (vpaned), bbox, TRUE, TRUE);
+/* log */
+  bbox = gtk_hbox_new (FALSE, 0);
+  gtk_paned_pack2 (GTK_PANED (vpaned), bbox, TRUE, FALSE);
   gtk_widget_show (bbox);
 
   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+
   gtk_box_pack_start (GTK_BOX (bbox), scrolled_window, TRUE, TRUE, 0);
+  
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
 				  GTK_POLICY_AUTOMATIC,
 				  GTK_POLICY_ALWAYS);
@@ -1556,42 +1070,31 @@ create_diff_window (void)
     gtk_widget_show (view_diag);
     gtk_container_add (GTK_CONTAINER (scrolled_window), view_diag);
   }
+  
+  /*moved buttons up to here for neatness*/
+  vbox3 = gtk_vbox_new (FALSE, 0);
+  vbox4 = gtk_vbox_new (FALSE, 0);
+  
+  button = shortcut_button (vbox3, GTK_STOCK_GO_UP, (gpointer) cb_next_diff, (gpointer) ((long) 0),TRUE);
+  button = shortcut_button (vbox3, GTK_STOCK_GO_DOWN, (gpointer) cb_next_diff, (gpointer) ((long) 1),TRUE);
+  
+  button = shortcut_button (vbox4, GTK_STOCK_CLEAR, (gpointer) on_clear_show_diag, (gpointer) text,TRUE);
+  button = shortcut_button (vbox4, GTK_STOCK_QUIT, (gpointer) delete_event, NULL,TRUE);
 
-/* another visible/invisible box */
-  patch_label_box = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), patch_label_box, FALSE, TRUE, 0);
-  gtk_widget_show (patch_label_box);
+  gtk_box_pack_start (GTK_BOX (bbox), vbox3, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (bbox), vbox4, FALSE, TRUE, 0);
 
-  viewW = gtk_text_view_new ();
-  what_dir = gtk_text_view_get_buffer (GTK_TEXT_VIEW (viewW));
-  gtk_text_view_set_cursor_visible ((GtkTextView *) viewW, FALSE);
-  gtk_text_view_set_editable ((GtkTextView *) viewW, FALSE);
-  gtk_text_view_set_wrap_mode ((GtkTextView *) viewW, GTK_WRAP_NONE);
-
-  gtk_box_pack_start (GTK_BOX (patch_label_box), viewW, TRUE, TRUE, 0);
-  gtk_widget_show (viewW);
-  if (!patching)
-    gtk_widget_hide (patch_label_box);
+  gtk_widget_show (vbox3);
+  gtk_widget_show (vbox4);
 
 /* last box on bottom */
-  bbox = gtk_hbox_new (TRUE, 0);
-/*  bbox = gtk_hbutton_box_new ();*/
-  /* gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_END); */
-  gtk_box_pack_start (GTK_BOX (vbox), bbox, FALSE, TRUE, 0);
-  gtk_widget_show (bbox);
-
-  button = shortcut_button (bbox,GTK_STOCK_CLEAR, (gpointer) on_clear_show_diag, (gpointer) text,TRUE);
-
-
-  button = shortcut_button (bbox, GTK_STOCK_GO_DOWN, (gpointer) cb_next_diff, (gpointer) ((long) 1),TRUE);
-  gtk_widget_grab_default (button);
-
-  button = shortcut_button (bbox, GTK_STOCK_GO_UP, (gpointer) cb_next_diff, (gpointer) ((long) 0),TRUE);
+ /* 
   next_file = shortcut_button (bbox, _("Next file"), (gpointer) cb_next_file, (gpointer) ((long) 1),FALSE);
-  prev_file = shortcut_button (bbox, _("Previous file"), (gpointer) cb_next_file, (gpointer) ((long) 0),FALSE);
-  /*gtk_widget_hide(next_file);
-  gtk_widget_hide(prev_file);*/
-  button = shortcut_button (bbox, GTK_STOCK_QUIT, (gpointer) delete_event, NULL,TRUE);
+  prev_file = shortcut_button (bbox, _("Previous file"), (gpointer) cb_next_file, (gpointer) ((long) 0),FALSE);*/
+  /*combo box - file list not growing...meant when directory selected*/
+ /*gtk_widget_hide(next_file);
+  gtk_widget_hide(prev_file);
+*/
 
   /* gtk_widget_set_events (drawA,GDK_EXPOSURE_MASK); */
 
@@ -1604,11 +1107,6 @@ create_diff_window (void)
   g_signal_connect (G_OBJECT (viewR), "drag_data_received", G_CALLBACK (on_drag_data_received), (gpointer) NULL);
 
   g_signal_connect (G_OBJECT (scrolled_windowR), "button_press_event", G_CALLBACK (cb_wheel), (gpointer) NULL);
-/*  g_signal_connect (G_OBJECT (viewR), "button_press_event", G_CALLBACK (cb_wheel), (gpointer) NULL);
-  g_signal_connect (G_OBJECT (viewL), "button_press_event", G_CALLBACK (cb_wheel), (gpointer) NULL);*/
- 
-  /*g_signal_connect (G_OBJECT (viewR), "set-scroll-adjustments", G_CALLBACK (scroll_adjustments), (gpointer) NULL);
-  g_signal_connect (G_OBJECT (viewL), "set-scroll-adjustments", G_CALLBACK (scroll_adjustments), (gpointer) NULL);*/
 
 
   g_signal_connect (G_OBJECT (diff), "delete_event", G_CALLBACK (delete_event), (gpointer) GTK_WIDGET (diff));
