@@ -102,6 +102,7 @@ xf_selection (char *title, int caso, GdkColor *color)
     dialogo = gtk_file_selection_new (title);
     ok_object = GTK_OBJECT (GTK_FILE_SELECTION (dialogo)->ok_button);
     ko_object = GTK_OBJECT (GTK_FILE_SELECTION (dialogo)->cancel_button);
+    gtk_widget_set_size_request (dialogo, 600, 500);
     break;
   }
   g_signal_connect (G_OBJECT(ok_object), "clicked", G_CALLBACK (xf_button), (gpointer) ((long) 1));
@@ -155,15 +156,7 @@ xf_selector (char *title, int caso, GdkColor *color)
 }
 
 /* public dialog functions: */
-char *
-xf_fontselect (char *title, char *aux)
-{
-  char *fuente;
-  fuente=aux;
-  while ((fuente[0]==' ') && (fuente[0]!=0)) fuente++;
-printf("TRACE:in=%s\n",fuente);
-  return xf_selector(title,FONT_SELECTION,(GdkColor *)fuente);
-}
+
 
 char *
 xf_colorselect (char *title, GdkColor *color)
@@ -561,7 +554,7 @@ get_the_file (char *file)
   char *fileS;
   /*  */
   /*  */
-  fileS = xf_fileselect (_("Directory or file selection"));
+  fileS = xf_fileselect (_("File selection"));
   if (fileS)
   {
     if ((file) && (strcmp (file, fileS) == 0))
@@ -594,7 +587,7 @@ prompt_path (char *message, char *file)
   if (!texto)
     xfdiff_abort (E_MALLOC);
   sprintf (texto, "%s\n%s", message, _("Please select it in the next dialog."));
-  /*  */
+
   if (xf_dlg_ask (diff,texto)==DLG_RC_CANCEL)
     return NULL;
 
@@ -818,57 +811,26 @@ update_titlesP (void)
   char *texto;
   patched_file *thisF;
   thisF = currentF;
-  if (patching)
-  {
-    if (what_dir)
-    {
-      clear_text_buffer (what_dir);
-      if (!fileP)
-      {
-	utf8_insert_tag (what_dir, _(no_patch), "bg_red");
-      }
-      else
-      {
-	utf8_insert_tag  (what_dir, _("Patch: "),"bg_bluewhite");
-	utf8_file_insert (what_dir,fileP);
-      }
-      if (!fileD)
-      {
-	utf8_insert_tag (what_dir, _(no_patch_dir), "bg_red");
-      }
-      else
-      {
-        utf8_insert_tag (what_dir, _(" applied at: "), "bg_bluewhite");
-	utf8_file_insert (what_dir, fileD);
-	utf8_insert (what_dir, "\n");
-      }
-    }
 
-    if (!fileP)
-      texto = no_patch;
-    else
-    {
-      if (!fileD)
-	texto = no_patch_dir;
-      else
-	texto = (N_("Press OK to see patch diffs"));
-    }
-  }
-  else
-  {				/* !patching */
     if (!filename[1])
       texto = no_right_path;
     else
       texto = filename[1];
-  }
+
   if (thisF)
     texto = thisF->newfile;
 
   if (titleP)
   {
-    clear_text_buffer (titleP);
-    utf8_file_insert (titleP, _(texto));
-    utf8_insert (what_dir, "\n");
+
+  if (items != NULL)
+  {
+    g_list_free (items);
+    items = NULL;
+  }
+        items = g_list_append (items, _(texto));
+    if (titleP)
+      gtk_combo_set_popdown_strings (GTK_COMBO (titleP), items);
   }
 
   if (items != NULL)
@@ -894,15 +856,14 @@ update_titlesP (void)
   }
   else
   {
-    if (!patching)
-    {
+
       if (filename[0])
 	texto = filename[0];
       else
 	texto = no_left_path;
-    }
+
     items = g_list_append (items, _(texto));
-    if (titleP)
+    if (titleD)
       gtk_combo_set_popdown_strings (GTK_COMBO (titleD), items);
   }
 }
